==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/ts/Projection_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Projection</name>
    <message>
        <location filename="../Projection.js" line="+70"/>
        <source>Projection Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narzędzia projekcyjne</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show projection tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż narzędzi projekcyjnych</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Projection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Projekcja</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation type="unfinished">Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation type="unfinished">Punkt docelowy</translation>
    </message>
</context>
<context>
    <name>ProjectionCylindrical</name>
    <message>
        <source>Cylinder axis start point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cylinder punkt początkowy osi</translation>
    </message>
    <message>
        <source>Cylinder axis end point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cylinder punkt końcowy osi</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/ts/Projection_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Projection</name>
    <message>
        <location filename="../Projection.js" line="+82"/>
        <source>Projection Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia rzutowania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show projection tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetla narzędzia rzutowania</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Projection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Rzutowanie</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation>Punkt docelowy</translation>
    </message>
</context>
<context>
    <name>ProjectionCylindrical</name>
    <message>
        <source>Cylinder axis start point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cylinder punkt początkowy osi</translation>
    </message>
    <message>
        <source>Cylinder axis end point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cylinder punkt końcowy osi</translation>
    </message>
</context>
</TS>
